@@ -1,4 +1,3 @@
-use crossbeam_channel::{bounded, Sender};
 use itertools::Itertools;
 use polytype::{Context, Type, TypeSchema};
 use rayon::join;
@@ -11,6 +10,7 @@ use std::sync::atomic::{AtomicUsize, Ordering};
 use std::sync::{Arc, RwLock};
 
 use super::{Expression, Language, LinkedList};
+use utils::{bounded, Sender};
 use {ECFrontier, Task};
 
 const BOUND_VAR_COST: f64 = 0.1;
@@ -115,7 +115,7 @@ pub fn induce<O: Sync>(
                 let (tx, rx) = bounded(100);
                 let (_, proposals) = join(
                     || dsl.propose_inventions(&rescored_frontiers, params.arity, tx),
-                    || rx.iter().collect::<Vec<_>>(),
+                    || rx.collect::<Vec<_>>(),
                 );
                 if cfg!(feature = "verbose") {
                     eprintln!("COMPRESSION: proposed {} fragments", proposals.len())
@@ -193,7 +193,8 @@ impl Language {
         topk: usize,
         topk_use_only_likelihood: bool,
     ) -> RescoredFrontier<'a> {
-        let xs = f.1
+        let xs = f
+            .1
             .iter()
             .map(|&(ref expr, _, loglikelihood)| {
                 let logprior = self.uses(f.0, expr).0;
@@ -224,7 +225,8 @@ impl Language {
         let joint_mdl = self.inside_outside(frontiers, pseudocounts);
         let nparams = self.primitives.len() + self.invented.len();
         let structure = (self.primitives.len() as f64)
-            + self.invented
+            + self
+                .invented
                 .iter()
                 .map(|&(ref expr, _, _)| expression_structure(expr))
                 .sum::<f64>();
@@ -267,7 +269,8 @@ impl Language {
         let u = frontiers
             .par_iter()
             .flat_map(|f| {
-                let lu = f.1
+                let lu = f
+                    .1
                     .iter()
                     .map(|&(ref expr, _logprior, loglikelihood)| {
                         let (logprior, u) = self.uses(f.0, expr);
@@ -293,7 +296,7 @@ impl Language {
                     u
                 },
             );
-        let joint_mdl = rx.iter().take(frontiers.len()).sum();
+        let joint_mdl = rx.take(frontiers.len()).sum();
         (joint_mdl, u)
     }
 
@@ -360,7 +363,8 @@ impl Language {
                             template.push_front(ctx.to_mut().new_variable())
                         }
                         // unification cannot fail, so we can safely unwrap:
-                        if ctx.to_mut()
+                        if ctx
+                            .to_mut()
                             .unify(&frag_tp, &Type::from(template.clone()))
                             .is_err()
                         {
@@ -465,7 +469,8 @@ impl Language {
         i: usize,
         expr: &Expression,
     ) -> bool {
-        let results: Vec<_> = f.1
+        let results: Vec<_> = f
+            .1
             .iter_mut()
             .map(|x| self.rewrite_expression(&mut x.0, i, expr, 0))
             .collect();
@@ -511,6 +516,7 @@ impl Language {
     }
 
     /// Yields expressions that may have free variables.
+    #[cfg_attr(feature = "cargo-clippy", allow(needless_pass_by_value))]
     fn propose_inventions(
         &self,
         frontiers: &[RescoredFrontier],
@@ -536,19 +542,19 @@ impl Language {
                         .map(|x: &AtomicUsize| x.fetch_add(1, Ordering::SeqCst))
                 };
                 match res {
-                    Some(2) if self.infer(&fragment_expr).is_ok() => {
-                        tx.send(fragment_expr)
-                            .expect("failed to send fragment proposal");
-                    }
+                    Some(2) if self.infer(&fragment_expr).is_ok() => tx
+                        .send(fragment_expr)
+                        .expect("failed to send fragment proposal"),
                     None => {
                         let mut h = findings.write().expect("hashmap was poisoned");
-                        let count = h.entry(fragment_expr.clone())
+                        let count = h
+                            .entry(fragment_expr.clone())
                             .or_insert_with(|| AtomicUsize::new(0));
                         if 2 == count.fetch_add(1, Ordering::SeqCst)
                             && self.infer(&fragment_expr).is_ok()
                         {
                             tx.send(fragment_expr)
-                                .expect("failed to send fragment proposal");
+                                .expect("failed to send fragment proposal")
                         }
                     }
                     _ => (),
