@@ -44,7 +44,6 @@ pub use self::eval::{
 };
 pub use self::parser::ParseError;
 
-use crossbeam_channel::bounded;
 use polytype::{Context, Type, TypeSchema, UnificationError};
 use rayon::spawn;
 use std::collections::{HashMap, VecDeque};
@@ -55,6 +54,7 @@ use std::ops::Index;
 use std::rc::Rc;
 use std::sync::Arc;
 
+use utils::bounded;
 use {ECFrontier, Task, EC};
 
 /// (representation) A Language is a registry for primitive and invented expressions in a
@@ -177,7 +177,7 @@ impl Language {
             let termination_condition = |expr, logprior| tx.send((expr, logprior)).is_err();
             enumerator::run(&dsl, tp, termination_condition)
         });
-        Box::new(rx.into_iter())
+        Box::new(rx)
     }
 
     /// Update production probabilities and induce new primitives, with the guarantee that any
@@ -506,11 +506,13 @@ impl Language {
         // make cands as big as possible to prevent reallocation
         let mut cands = Vec::with_capacity(self.primitives.len() + self.invented.len() + env.len());
         // primitives and inventions
-        let prims = self.primitives
+        let prims = self
+            .primitives
             .iter()
             .enumerate()
             .map(|(i, &(_, ref tp, p))| (p, tp, Expression::Primitive(i)));
-        let invented = self.invented
+        let invented = self
+            .invented
             .iter()
             .enumerate()
             .map(|(i, &(_, ref tp, p))| (p, tp, Expression::Invented(i)));
@@ -825,7 +827,7 @@ where
     }
 }
 
-/// Liky [`task_by_evaluation`], but for use with a [`LazyEvaluator`].
+/// Like [`task_by_evaluation`], but for use with a [`LazyEvaluator`].
 ///
 /// [`LazyEvaluator`]: trait.LazyEvaluator.html
 /// [`task_by_evaluation`]: fn.task_by_evaluation.html
