@@ -96,6 +96,7 @@
 //! [`pcfg`]: pcfg/index.html
 //! [`unit`]: https://doc.rust-lang.org/std/primitive.unit.html
 
+#[macro_use]
 extern crate crossbeam_channel;
 extern crate itertools;
 #[macro_use]
@@ -108,12 +109,15 @@ extern crate nom;
 extern crate polytype;
 extern crate rand;
 extern crate rayon;
+extern crate term_rewriting;
 
 pub mod domains;
 mod ec;
 mod gp;
 pub mod lambda;
 pub mod pcfg;
+pub mod trs;
+mod utils;
 pub use ec::*;
 pub use gp::*;
 
